@@ -1,4 +1,11 @@
 package Net::APE::Cmd::Inlinepush;
+BEGIN {
+  $Net::APE::Cmd::Inlinepush::AUTHORITY = 'cpan:GETTY';
+}
+BEGIN {
+  $Net::APE::Cmd::Inlinepush::VERSION = '0.003';
+}
+# ABSTRACT: Executing an inline push on the APE-Server
 use Moose;
 extends 'Net::APE::Cmd';
 
@@ -6,17 +13,6 @@ with qw(
 	Net::APE::Cmd::Role::Data
 );
 
-=head1 NAME
-
-Net::APE::Cmd::Inlinepush - Executing an inline push on the APE-Server
-
-=head1 SYNOPSIS
-
-  use Net::APE::Cmd::Inlinepush;
-
-=head1 DESCRIPTION
-
-=cut
 
 has '+name' => (
 	default => sub { 'inlinepush' },
@@ -51,20 +47,36 @@ before get_request_hash => sub {
 
 1;
 
+
+__END__
 =pod
 
+=head1 NAME
+
+Net::APE::Cmd::Inlinepush - Executing an inline push on the APE-Server
+
+=head1 VERSION
+
+version 0.003
+
+=head1 SYNOPSIS
+
+  use Net::APE::Cmd::Inlinepush;
+
+=head1 DESCRIPTION
+
 =head1 METHODS
 
 =head1 AUTHOR
 
-Torsten Raudssus <torsten@raudssus.de>
+Torsten Raudssus <torsten@raudssus.de> L<http://www.raudssus.de/>
 
-=head1 COPYRIGHT & LICENSE 
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Torsten Raudssus, all rights reserved.
+This software is copyright (c) 2010 by Raudssus Social Software.
 
-This library is free software; you can redistribute it and/or modify it under the same terms as 
-Perl itself, either Perl version 5.8.8 or, at your option, any later version of Perl 5 you may 
-have available.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
